@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2012      Dennis Nienhüser <nienhueser@kde.org>
+// SPDX-FileCopyrightText: 2012 Dennis Nienhüser <nienhueser@kde.org>
 //
 
 #include <QApplication>
@@ -24,7 +19,7 @@ int main(int argc, char** argv)
     MarbleWidget *mapWidget = new MarbleWidget();
 
     // Load the OpenStreetMap map
-    mapWidget->setMapThemeId("earth/bluemarble/bluemarble.dgml");
+    mapWidget->setMapThemeId(QStringLiteral("earth/bluemarble/bluemarble.dgml"));
 
     mapWidget->setProjection( Mercator );
 
@@ -37,7 +32,7 @@ int main(int argc, char** argv)
     mapWidget->setShowScaleBar(false);
 
     foreach ( AbstractFloatItem * floatItem, mapWidget->floatItems() )
-        if ( floatItem && floatItem->nameId() == "compass" ) {
+        if (floatItem && floatItem->nameId() == QLatin1String("compass")) {
 
             // Put the compass onto the left hand side
             floatItem->setPosition( QPoint( 10, 10 ) );
