@@ -233,7 +233,7 @@ QDateTime BookmarkSyncManager::lastSync() const
     const QString last = d->lastSyncedKmlPath();
     if (last.isEmpty())
         return QDateTime();
-    return QFileInfo(last).created();
+    return QFileInfo(last).metadataChangeTime();
 }
 
 bool BookmarkSyncManager::isBookmarkSyncEnabled() const
@@ -666,6 +666,7 @@ void BookmarkSyncManager::resolveConflict( MergeItem *item )
             diffItem = d->m_diffA.first();
             break;
         }
+        Q_FALLTHROUGH();
     case MergeItem::B:
         diffItem = d->m_conflictItem;
         break;
