@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2014      Torsten Rahn <rahn@kde.org>
+// SPDX-FileCopyrightText: 2014 Torsten Rahn <rahn@kde.org>
 //
 
 // Local
@@ -120,11 +115,7 @@ bool StereographicProjection::screenCoordinates( const GeoDataCoordinates &coord
     y = viewport->height() / 2 - y;
 
     // Skip placemarks that are outside the screen area
-    if ( x < 0 || x >= viewport->width() || y < 0 || y >= viewport->height() ) {
-        return false;
-    }
-
-    return true;
+    return !(x < 0 || x >= viewport->width() || y < 0 || y >= viewport->height());
 }
 
 bool StereographicProjection::screenCoordinates( const GeoDataCoordinates &coordinates,
