@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2012 Torsten Rahn <tackat@kde.org>
+// SPDX-FileCopyrightText: 2012 Torsten Rahn <tackat@kde.org>
 //
 
 
@@ -15,7 +10,6 @@
 #include <QDebug>
 #include <QXmlInputSource>
 #include <QXmlSimpleReader>
-#include <QStringList>
 #include "svgxmlhandler.h"
 
 void parseSvg( const QString & svgFilename, QDataStream * out, const QString & path, int header ) {
